<?php

namespace Shpopping\Category\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Shpopping\Category\Actions\CategoryAction;
use Shpopping\Category\Http\Requests\CategoryActionRequest;
use Shpopping\Category\Http\Resources\CategoryResource;
use Shpopping\Category\Models\Category;

/**
 * Admin web controller class.
 */
class CategoryActionController extends BaseController
{

    /**
     * Action controller function for category.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CategoryActionRequest $request, Category $category, $action)
    {
        try {
            $request = $request->all();
            $category = CategoryAction::run($action, $category, $request);

            $data = new CategoryResource($category);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('category::category.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('category/category/' . $category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('category/category/' . $category->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
