<?php

namespace Shpopping\Category\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Shpopping\Category\Models\Category;

class CategoryPolicy
{

    use CategoryAction;
    use CategoryWorkflow;

    /**
     * Determine if the given user can view the category.
     *
     * @param Authenticatable $user
     * @param Category $category
     *
     * @return bool
     */
    public function view(Authenticatable $user, Category $category)
    {
        if ($authUser->canDo('category.category.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $category->is_owner;
    }

    /**
     * Determine if the given user can create a category.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('category.category.create');
    }

    /**
     * Determine if the given user can update the given category.
     *
     * @param Authenticatable $user
     * @param Category $category
     *
     * @return bool
     */
    public function update(Authenticatable $user, Category $category)
    {
        if ($user->canDo('category.category.edit') && $user->isAdmin()) {
            return true;
        }

        return $category->is_owner;
    }

    /**
     * Determine if the given user can delete the given category.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Category $category)
    {
        return $category->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
